"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepWorker = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const shared_1 = require("./shared");
const microWorker = require('./microWorker');
class StepWorker {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('JobSchedular');
        this.featureFlag = new shared_1.FeatureFlag();
    }
    async process(message) {
        try {
            const isNewJobSchedular = await this.featureFlag.isNewJobSchedular();
            if (isNewJobSchedular) {
                this.logger.info('Going with new job schedular flow');
                await this.processNewStepTrigger(message);
            }
            else {
                this.logger.info('Going with old job schedular flow');
                await this.processOldStepTrigger(message);
            }
        }
        catch (error) {
            this.logger.warn((0, node_util_1.inspect)(error));
        }
    }
    async processOldStepTrigger(message) {
        const accessClient = internal_clients_1.AccessClientFactory.getClient();
        const { rawClient, context } = accessClient.getRawClientAndContext();
        global.accessClient = rawClient;
        global.accessClientContext = context;
        const workerPromisify = (0, node_util_1.promisify)(microWorker.bind(microWorker));
        await workerPromisify(message);
    }
    async processNewStepTrigger(message) {
        try {
            const handler = shared_1.CommandFactory.getHandler(message.payload, message.jFrogPipelinesSessionId);
            await handler.handle();
        }
        catch (error) {
            this.logger.warn(`Received ${(0, node_util_1.inspect)(error)} while processing ${(0, node_util_1.inspect)(message)}`);
        }
    }
}
exports.StepWorker = StepWorker;
//# sourceMappingURL=StepWorker.js.map