"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const StepScheduler_1 = require("../StepScheduler");
const modules_1 = require("../modules");
const RunDao_1 = require("../modules/RunDao");
const Adapter = __importStar(require("../Adapter"));
const ApiAdapter = Adapter.default;
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: { config: { apiUrl: 'http://example.com', controlPlaneVersion: '1.23.6', defaultBatchSize: 100 } }
}));
const mockPipelinesClient = {
    getExecutionNodes: jest.fn().mockResolvedValue({ available: 1 }),
    queueToNodePool: jest.fn().mockResolvedValue(true),
    putStepById: jest.fn().mockResolvedValue(true),
    putStepletById: jest.fn().mockResolvedValue(true),
    pipelineSource: jest.fn().mockResolvedValue({ artifactoryTokenPermissions: ['w'], id: 1 })
};
jest.mock('@jfrog-pipelines/internal-clients', () => ({
    PipelinesClient: jest.fn().mockImplementation(() => {
        return mockPipelinesClient;
    }),
    AccessClientFactory: {
        getClient: jest.fn().mockImplementation(() => {
            return {
                createAccessTokenRequest: jest.fn().mockResolvedValue({ accessToken: 'token' })
            };
        })
    }
}));
jest.mock('@jfrog-pipelines/amqp-client', () => ({
    AmqpFactory: {
        getConnectionManager: jest.fn()
    },
    AmqpPublisher: jest.fn()
}));
jest.spyOn(ApiAdapter.prototype, 'postStepletConsoles').mockImplementation((...params) => {
    const callback = params[1];
    callback(null, true);
});
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        ...jest.requireActual('@jfrog-pipelines/logger'),
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            }),
            configure: jest.fn(),
            logEvent: jest.fn()
        }
    };
});
describe('Step scheduler test cases', () => {
    it('should create step scheduler', () => {
        const stepScheduler = new StepScheduler_1.StepScheduler([], 10, {}, []);
        expect(stepScheduler).toBeDefined();
    });
    it('should not fail when empty waitingGroups are passed', async () => {
        const stepScheduler = new StepScheduler_1.StepScheduler([], 1, {}, []);
        await stepScheduler.queueStepsToNodePool();
        expect(true).toBe(true);
    });
    it('should queue one waitingGroup when available capacity is 1', async () => {
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 614,
                runId: 10291,
                stepId: 29121,
                stepletId: 29231,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getStepletsByStepletIds').mockResolvedValue([
            {
                id: 2923,
                stepId: 2912,
                affinityGroup: 'group',
                configPropertyBag: {}
            },
            {
                id: 29231,
                stepId: 29121,
                affinityGroup: 'group',
                configPropertyBag: {}
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getSteps').mockResolvedValue([
            {
                id: 2912,
                runId: 1029,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            },
            {
                id: 29121,
                runId: 10291,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            }
        ]);
        const affinityGroupManager = new modules_1.AffinityGroupManager(new modules_1.ApiDataAdapter({}));
        const waitingGroups = await affinityGroupManager.getAffinityGroups();
        expect(waitingGroups).toHaveLength(2);
        const stepScheduler = new StepScheduler_1.StepScheduler(waitingGroups, 1, { name: 'default' }, [{ id: 1 }]);
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'findById')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'updateByInstance')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        await stepScheduler.queueStepsToNodePool();
        expect(mockPipelinesClient.queueToNodePool).toHaveBeenCalledTimes(1);
    });
    it('should skip the waitingGroup when no nodes', async () => {
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 614,
                runId: 10291,
                stepId: 29121,
                stepletId: 29231,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getStepletsByStepletIds').mockResolvedValue([
            {
                id: 2923,
                stepId: 2912,
                affinityGroup: 'group',
                configPropertyBag: {}
            },
            {
                id: 29231,
                stepId: 29121,
                affinityGroup: 'group',
                configPropertyBag: {}
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getSteps').mockResolvedValue([
            {
                id: 2912,
                runId: 1029,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            },
            {
                id: 29121,
                runId: 10291,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            }
        ]);
        const affinityGroupManager = new modules_1.AffinityGroupManager(new modules_1.ApiDataAdapter({}));
        const waitingGroups = await affinityGroupManager.getAffinityGroups();
        expect(waitingGroups).toHaveLength(2);
        for (const waitingGroup of waitingGroups) {
            waitingGroup.skipByNoNode = true;
        }
        const stepScheduler = new StepScheduler_1.StepScheduler(waitingGroups, 1, { name: 'default' }, [{ id: 1 }]);
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'findById')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'updateByInstance')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        await stepScheduler.queueStepsToNodePool();
        expect(mockPipelinesClient.queueToNodePool).toHaveBeenCalledTimes(0);
    });
    it('should skip the waitingGroup when skipByNodePoolPermissions', async () => {
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 614,
                runId: 10291,
                stepId: 29121,
                stepletId: 29231,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getStepletsByStepletIds').mockResolvedValue([
            {
                id: 2923,
                stepId: 2912,
                affinityGroup: 'group',
                configPropertyBag: {}
            },
            {
                id: 29231,
                stepId: 29121,
                affinityGroup: 'group',
                configPropertyBag: {}
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getSteps').mockResolvedValue([
            {
                id: 2912,
                runId: 1029,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            },
            {
                id: 29121,
                runId: 10291,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            }
        ]);
        const affinityGroupManager = new modules_1.AffinityGroupManager(new modules_1.ApiDataAdapter({}));
        const waitingGroups = await affinityGroupManager.getAffinityGroups();
        expect(waitingGroups).toHaveLength(2);
        for (const waitingGroup of waitingGroups) {
            waitingGroup.skipByNodePoolPermissions = true;
        }
        const stepScheduler = new StepScheduler_1.StepScheduler(waitingGroups, 1, { name: 'default' }, [{ id: 1 }]);
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'findById')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'updateByInstance')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        await stepScheduler.queueStepsToNodePool();
        expect(mockPipelinesClient.queueToNodePool).toHaveBeenCalledTimes(0);
    });
    it('should skip the waitingGroup when skipByNonRootEnforcement', async () => {
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 614,
                runId: 10291,
                stepId: 29121,
                stepletId: 29231,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getStepletsByStepletIds').mockResolvedValue([
            {
                id: 2923,
                stepId: 2912,
                affinityGroup: 'group',
                configPropertyBag: {}
            },
            {
                id: 29231,
                stepId: 29121,
                affinityGroup: 'group',
                configPropertyBag: {}
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getSteps').mockResolvedValue([
            {
                id: 2912,
                runId: 1029,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            },
            {
                id: 29121,
                runId: 10291,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            }
        ]);
        const affinityGroupManager = new modules_1.AffinityGroupManager(new modules_1.ApiDataAdapter({}));
        const waitingGroups = await affinityGroupManager.getAffinityGroups();
        expect(waitingGroups).toHaveLength(2);
        for (const waitingGroup of waitingGroups) {
            waitingGroup.skipByNonRootEnforcement = true;
        }
        const stepScheduler = new StepScheduler_1.StepScheduler(waitingGroups, 1, { name: 'default' }, [{ id: 1 }]);
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'findById')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'updateByInstance')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        await stepScheduler.queueStepsToNodePool();
        expect(mockPipelinesClient.queueToNodePool).toHaveBeenCalledTimes(0);
    });
    it('should queue one waitingGroup when available capacity is 1 and isStepUsingLocalArtifactory', async () => {
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 614,
                runId: 10291,
                stepId: 29121,
                stepletId: 29231,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getStepletsByStepletIds').mockResolvedValue([
            {
                id: 2923,
                stepId: 2912,
                affinityGroup: 'group',
                configPropertyBag: {}
            },
            {
                id: 29231,
                stepId: 29121,
                affinityGroup: 'group',
                configPropertyBag: {}
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getSteps').mockResolvedValue([
            {
                id: 2912,
                runId: 1029,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            },
            {
                id: 29121,
                runId: 10291,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            }
        ]);
        const affinityGroupManager = new modules_1.AffinityGroupManager(new modules_1.ApiDataAdapter({}));
        const waitingGroups = await affinityGroupManager.getAffinityGroups();
        expect(waitingGroups).toHaveLength(2);
        waitingGroups[0].isStepUsingLocalArtifactory = true;
        const stepScheduler = new StepScheduler_1.StepScheduler(waitingGroups, 1, { name: 'default' }, [{ id: 1 }]);
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'findById')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'updateByInstance')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        await stepScheduler.queueStepsToNodePool();
        expect(mockPipelinesClient.queueToNodePool).toHaveBeenCalledTimes(1);
    });
    it('should queue one waitingGroup when available capacity is 1 and isStepUsingLocalArtifactory having valid project', async () => {
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 614,
                runId: 10291,
                stepId: 29121,
                stepletId: 29231,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getStepletsByStepletIds').mockResolvedValue([
            {
                id: 2923,
                stepId: 2912,
                affinityGroup: 'group',
                configPropertyBag: {}
            },
            {
                id: 29231,
                stepId: 29121,
                affinityGroup: 'group',
                configPropertyBag: {}
            }
        ]);
        jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getSteps').mockResolvedValue([
            {
                id: 2912,
                runId: 1029,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            },
            {
                id: 29121,
                runId: 10291,
                affinityGroup: 'group',
                groupStartedAt: new Date()
            }
        ]);
        const affinityGroupManager = new modules_1.AffinityGroupManager(new modules_1.ApiDataAdapter({}));
        const waitingGroups = await affinityGroupManager.getAffinityGroups();
        expect(waitingGroups).toHaveLength(2);
        waitingGroups[0].isStepUsingLocalArtifactory = true;
        waitingGroups[0].projectId = 1;
        waitingGroups[0].pipelineSourceId = 1;
        const stepScheduler = new StepScheduler_1.StepScheduler(waitingGroups, 1, { name: 'default' }, [{ id: 1 }]);
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'findById')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        jest
            .spyOn(RunDao_1.RunDao.prototype, 'updateByInstance')
            .mockResolvedValue({ id: 1, systemPropertyBag: {}, toJSON: jest.fn().mockReturnThis() });
        await stepScheduler.queueStepsToNodePool();
        expect(mockPipelinesClient.queueToNodePool).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=StepScheduler.test.js.map