"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const microservice_1 = require("@jfrog-pipelines/microservice");
const logger_1 = require("@jfrog-pipelines/logger");
const queueExternalStepsNew_1 = require("../queueExternalStepsNew");
const waitingStepsByRunAdjacency_1 = require("../../waitingStepsByRunAdjacency");
const waitingGroupManager_1 = require("../../waitingGroupManager");
const tryAndQueueExternalStepsNew_1 = require("../tryAndQueueExternalStepsNew");
function getExecutionNodesMockImplementation() {
    return { active: 0, allowed: 0, available: 1 };
}
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: {
        config: {
            apiUrl: 'http://example.com',
            controlPlaneVersion: '1.23.6',
            defaultBatchSize: 100,
            jfrogPipelineSessionId: 'Testing123',
            apiToken: 'Testing1234'
        }
    }
}));
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                warn: jest.fn(),
                info: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
jest.mock('../../acl', () => {
    return {
        NodePoolRepository: jest.fn().mockImplementation(() => {
            return {
                getExecutionNodes: getExecutionNodesMockImplementation
            };
        })
    };
});
function mockResolveQueueSteps() {
    return Promise.resolve();
}
function mockResolveSetReadyAt() {
    return Promise.resolve();
}
function mockResolveReleaseLock() {
    return Promise.resolve();
}
const mockLockTimeoutMS = 60000;
const mockLockObject = new microservice_1.Lock(1, 'test', mockLockTimeoutMS);
const group = [{ projectId: 1, isExternal: true }];
describe('Testing for success state', () => {
    let queueExternalSteps;
    beforeEach(() => {
        queueExternalSteps = new queueExternalStepsNew_1.QueueExternalSteps(group, 'Testing123', 'Testing1234');
    });
    it('should be defined', () => {
        expect(queueExternalSteps).toBeDefined();
    });
    it('should queue external steps', async () => {
        const createSpy = jest.spyOn(microservice_1.Lock, 'create').mockResolvedValueOnce(mockLockObject);
        const spy1 = jest.spyOn(microservice_1.Lock.prototype, 'obtainLock').mockResolvedValueOnce();
        const spy2 = jest.spyOn(waitingStepsByRunAdjacency_1.WaitingStepsByRunAdjacency, 'getWaitingStepsByRunAdjacencies').mockResolvedValueOnce(group);
        const spy3 = jest.spyOn(waitingGroupManager_1.WaitingGroupManager.prototype, 'setReadyAt').mockImplementationOnce(mockResolveSetReadyAt);
        const spy4 = jest
            .spyOn(tryAndQueueExternalStepsNew_1.TryAndQueueExternalSteps.prototype, 'queueSteps')
            .mockImplementationOnce(mockResolveQueueSteps);
        const spy5 = jest.spyOn(microservice_1.Lock.prototype, 'releaseLock').mockImplementationOnce(mockResolveReleaseLock);
        await queueExternalSteps.queueExternalSteps();
        expect(createSpy).toHaveBeenCalledTimes(1);
        expect(spy1).toHaveBeenCalledTimes(1);
        expect(spy2).toHaveBeenCalledTimes(1);
        expect(spy3).toHaveBeenCalledTimes(1);
        expect(spy4).toHaveBeenCalledTimes(1);
        expect(spy5).toHaveBeenCalledTimes(1);
    });
    it('should give info log if cannot queue external Step because lock already exists', async () => {
        const createSpy = jest.spyOn(microservice_1.Lock, 'create').mockResolvedValueOnce(null);
        const releaseSpy = jest.spyOn(microservice_1.Lock.prototype, 'releaseLock').mockResolvedValueOnce();
        await queueExternalSteps.queueExternalSteps();
        expect(createSpy).toHaveBeenCalledTimes(1);
        expect(releaseSpy).toHaveBeenCalledTimes(0);
        expect(logger.info).toHaveBeenCalledWith(`Cannot queue external Step with projectId: 1 because lock Already Exists with name stepService-externalSteps-1`);
    });
    it('should give warning log if cannot queue external Step because lock cannot be created', async () => {
        const mockError = 'error';
        const createSpy = jest.spyOn(microservice_1.Lock, 'create').mockResolvedValueOnce(mockLockObject);
        const obtainSpy = jest.spyOn(microservice_1.Lock.prototype, 'obtainLock').mockRejectedValueOnce(mockError);
        const releaseSpy = jest.spyOn(microservice_1.Lock.prototype, 'releaseLock').mockResolvedValueOnce();
        await queueExternalSteps.queueExternalSteps();
        expect(createSpy).toHaveBeenCalledTimes(1);
        expect(obtainSpy).toHaveBeenCalledTimes(1);
        expect(releaseSpy).toHaveBeenCalledTimes(1);
        expect(logger.warn).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=queueExternalStepsNew.test.js.map