"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const queueStepsToJobNodePool_1 = require("../queueStepsToJobNodePool");
const HUNDRED = 100;
const ONE_HUNDRED_ONE = 101;
const getProjectIntegrationByIdMockImplementation = jest.fn().mockImplementation((projectIntegrationId) => {
    if (projectIntegrationId === HUNDRED) {
        return { id: 100, masterIntegrationName: 'kubernetesConfig' };
    }
    if (projectIntegrationId === ONE_HUNDRED_ONE) {
        return { id: 101, masterIntegrationName: 'aws' };
    }
    throw new Error('error');
});
jest.mock('../../acl', () => {
    return {
        IntegrationRepository: jest.fn().mockImplementation(() => {
            return {
                getProjectIntegrationById: getProjectIntegrationByIdMockImplementation
            };
        })
    };
});
describe('queueStepsToJobNodePool test cases', () => {
    const queueStepsToJobNodePool = new queueStepsToJobNodePool_1.QueueStepsToJobNodePool();
    describe('checkEligibilityForQueuingToJobNodePool test cases', () => {
        it('should return true if the nodepool is kubernetes and execution type is job', async () => {
            const nodePool = {
                id: 1,
                projectIntegrationId: 100,
                providerMetadataPropertyBag: {
                    customTags: [{ Key: 'executionType', Value: 'JoB' }]
                },
                isOnDemand: true
            };
            const result = await queueStepsToJobNodePool.checkEligibilityForQueuingToJobNodePool(nodePool);
            const mockExpectedResult = true;
            expect(result).toStrictEqual(mockExpectedResult);
        });
        it('should return false if the nodepool is not of type kubernetes and execution type is job', async () => {
            const nodePool = {
                id: 1,
                projectIntegrationId: 101,
                providerMetadataPropertyBag: {
                    customTags: [{ key: 'executionType', value: 'JoB' }]
                },
                isOnDemand: true
            };
            const result = await queueStepsToJobNodePool.checkEligibilityForQueuingToJobNodePool(nodePool);
            const mockExpectedResult = false;
            expect(result).toStrictEqual(mockExpectedResult);
        });
        it('should return false if the nodepool is of type kubernetes and execution type is not job', async () => {
            const nodePool = {
                id: 1,
                projectIntegrationId: 100,
                providerMetadataPropertyBag: {
                    customTags: [{ key: 'executionType', value: 'nodePool' }]
                },
                isOnDemand: true
            };
            const result = await queueStepsToJobNodePool.checkEligibilityForQueuingToJobNodePool(nodePool);
            const mockExpectedResult = false;
            expect(result).toStrictEqual(mockExpectedResult);
        });
        it('should return false if the nodepool is of type kubernetes but custom tags dont exist', async () => {
            const nodePool = {
                id: 1,
                projectIntegrationId: 100,
                providerMetadataPropertyBag: {},
                isOnDemand: true
            };
            const result = await queueStepsToJobNodePool.checkEligibilityForQueuingToJobNodePool(nodePool);
            const mockExpectedResult = false;
            expect(result).toStrictEqual(mockExpectedResult);
        });
        it('should return false if the nodepool is static', async () => {
            const nodePool = {
                id: 1,
                projectIntegrationId: 100,
                providerMetadataPropertyBag: {},
                isOnDemand: false
            };
            const result = await queueStepsToJobNodePool.checkEligibilityForQueuingToJobNodePool(nodePool);
            const mockExpectedResult = false;
            expect(result).toStrictEqual(mockExpectedResult);
        });
        it('should throw error if projectIntegration cannot be extracted', async () => {
            const nodePool = {
                id: 1,
                projectIntegrationId: 102,
                providerMetadataPropertyBag: {},
                isOnDemand: true
            };
            await expect(queueStepsToJobNodePool.checkEligibilityForQueuingToJobNodePool(nodePool)).rejects.toThrow('error');
        });
    });
});
//# sourceMappingURL=queueStepsToJobNodePool.test.js.map