"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ApiIntegrationDataAdapter_1 = require("../ApiIntegrationDataAdapter");
const IntegrationRepository_1 = require("../IntegrationRepository");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: {
        config: {
            apiUrl: 'http://example.com',
            controlPlaneVersion: '1.23.6',
            defaultBatchSize: 100
        }
    }
}));
describe('IntegrationRepository Test cases', () => {
    const integrationRepository = new IntegrationRepository_1.IntegrationRepository();
    const adapter = ApiIntegrationDataAdapter_1.ApiIntegrationDataAdapter;
    it('should be defined', () => {
        expect(adapter).toBeDefined();
    });
    describe('getGroupProjects test cases', () => {
        it('should return all projects when no projectId is passed', async () => {
            const input = [];
            const spy = jest
                .spyOn(adapter.prototype, 'getProjectsByQuery')
                .mockResolvedValueOnce([{ id: 1 }, { id: 2 }]);
            const mockExpectedResult = [{ id: 1 }, { id: 2 }];
            const result = await integrationRepository.getGroupProjects(input);
            expect(spy).toHaveBeenCalledTimes(1);
            expect(result).toStrictEqual(mockExpectedResult);
        });
        it('should return relevant project when projectId is passed', async () => {
            const input = [1];
            const spy = jest.spyOn(adapter.prototype, 'getProjectsByQuery').mockResolvedValueOnce([{ id: 1 }]);
            const mockExpectedResult = [{ id: 1 }];
            const result = await integrationRepository.getGroupProjects(input);
            expect(spy).toHaveBeenCalledTimes(1);
            expect(result).toStrictEqual(mockExpectedResult);
        });
    });
    describe('getProjectIntegrationById test cases', () => {
        it('should return projectIntegration when passed by projectIntegrationId', async () => {
            const projectIntegrationId = 1;
            const spy = jest
                .spyOn(adapter.prototype, 'getProjectIntegrationsById')
                .mockResolvedValueOnce({ id: 1 });
            const result = await integrationRepository.getProjectIntegrationById(projectIntegrationId);
            const mockExpectedResult = { id: 1 };
            expect(result).toStrictEqual(mockExpectedResult);
            expect(spy).toHaveBeenCalledTimes(1);
        });
    });
});
//# sourceMappingURL=IntegrationRepository.test.js.map