import { Project } from '@jfrog-pipelines/data-access-layer';
import { ExecutionNodes, NodeAttributes, NodePoolAttributes } from '@jfrog-pipelines/types';
import { WaitingGroup } from '../../modules';
declare type Status = {
    code: number;
    name: string;
    group: string;
};
declare type StatusCodes = {
    [key: string]: Status;
};
export declare type NodePoolsByProjectId = {
    [key: number]: NodePoolAttributes[];
};
export declare type OrphanedNodePool = {
    name: string;
    projectId: number;
    isOrphaned: boolean;
    isOnDemand: boolean;
};
export declare type OrphanedOnDemandNodesByProjectId = {
    [key: number]: NodeAttributes[];
};
export declare type OrphanedNodesResponse = {
    orphanedOnDemandNodesByProjectId: OrphanedOnDemandNodesByProjectId;
    orphanedNodePools: OrphanedNodePool[];
};
export declare type AvailableNodeCountResponse = {
    totalGroupsThatCanBeQueued: number;
    cachedNodes: NodeAttributes[];
    activeNodesCount: number;
    cachedNodesCount: number;
};
export declare class NodePoolRepository {
    private readonly adapter;
    private readonly logger;
    constructor();
    getNodePools(query?: string): Promise<NodePoolAttributes[]>;
    getNodes(query?: string): Promise<NodeAttributes[]>;
    getProjectsAllowedNodePools(groupProjects: Project[]): Promise<NodePoolsByProjectId>;
    getOrphanedNodes(): Promise<OrphanedNodesResponse>;
    getAndFilterAvailableNodes(nodePoolId: number, statusCodes: StatusCodes): Promise<NodeAttributes[]>;
    getBuildPlaneMessagesCount(status: StatusCodes, nodePoolId: number): Promise<number>;
    findAvailableNodeCount(isOnDemandNodepool: boolean, processingGroups: WaitingGroup[], useRunAdjacency: boolean, buildPlaneMessagesCount: number, numberOfNodesNodepool: number, statusCodes: StatusCodes, nodes: NodeAttributes[], isCacheEnabledNodePool: boolean): AvailableNodeCountResponse;
    getExecutionNodes(): Promise<ExecutionNodes>;
    private getProcessingGroupsCount;
    private getActiveNodes;
    private getCachedNodes;
    private getProcessingNodes;
    private getTotalNodeCount;
    private filterAvailableNodes;
    private isAllowedNode;
    private isWaitingOrQueuedNode;
    private isProcessingNode;
    private isSuccessOrCachedNode;
    private isSuccessNode;
    private isCachedNode;
    private getOrphanedOnDemandNodes;
    private getOrphanedOnDemandNodesByProjectId;
    private getOrphanedNodePools;
}
export {};
