"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RejectWaitingGroupsByNodePools_1 = require("../RejectWaitingGroupsByNodePools");
describe('rejectWaitingGroupsByNodePools test cases', () => {
    const rejectWaitingGroupsByNodePools = new RejectWaitingGroupsByNodePools_1.RejectWaitingGroupsByNodePools();
    it('should return empty values when there is no waiting groups', () => {
        const availableNodePools = [
            { id: 1, name: 'nodePool1', numberOfNodes: 5 },
            { id: 1, name: 'nodePool2', numberOfNodes: 3 }
        ];
        const allNodePools = [
            { id: 1, name: 'nodePool1', numberOfNodes: 5 },
            { id: 1, name: 'nodePool2', numberOfNodes: 3 },
            { id: 3, name: 'nodePool3', numberOfNodes: 2 }
        ];
        const waitingGroups = [];
        const result = rejectWaitingGroupsByNodePools.rejectWaitingGroupsByNodePools(availableNodePools, allNodePools, waitingGroups);
        const mockExpectedResult = {
            waitingGroupsAfterFiltering: [],
            waitingForFreeNodePoolCapacity: []
        };
        expect(result).toStrictEqual(mockExpectedResult);
    });
    it('should return empty value for waitingForFreeNodePoolCapacity when group is external', () => {
        const availableNodePools = [
            { id: 1, name: 'nodePool1', numberOfNodes: 5 },
            { id: 1, name: 'nodePool2', numberOfNodes: 3 }
        ];
        const allNodePools = [
            { id: 1, name: 'nodePool1', numberOfNodes: 5 },
            { id: 1, name: 'nodePool2', numberOfNodes: 3 },
            { id: 3, name: 'nodePool3', numberOfNodes: 2 }
        ];
        const waitingGroups = [{ isExternal: true }];
        const result = rejectWaitingGroupsByNodePools.rejectWaitingGroupsByNodePools(availableNodePools, allNodePools, waitingGroups);
        const mockExpectedResult = {
            waitingGroupsAfterFiltering: [{ isExternal: true }],
            waitingForFreeNodePoolCapacity: []
        };
        expect(result).toStrictEqual(mockExpectedResult);
    });
    it('should return empty value for waitingForFreeNodePoolCapacity when group is waiting for freeNodePoolCapacity', () => {
        const availableNodePools = [
            { id: 1, name: 'nodePool1', numberOfNodes: 5 },
            { id: 1, name: 'nodePool2', numberOfNodes: 3 }
        ];
        const allNodePools = [
            { id: 1, name: 'nodePool1', numberOfNodes: 5 },
            { id: 1, name: 'nodePool2', numberOfNodes: 3 },
            { id: 3, name: 'nodePool3', numberOfNodes: 2 }
        ];
        const waitingGroups = [{ isExternal: false, waitingForFreeNodePoolCapacity: true }];
        const result = rejectWaitingGroupsByNodePools.rejectWaitingGroupsByNodePools(availableNodePools, allNodePools, waitingGroups);
        const mockExpectedResult = {
            waitingGroupsAfterFiltering: [{ isExternal: false, waitingForFreeNodePoolCapacity: true }],
            waitingForFreeNodePoolCapacity: []
        };
        expect(result).toStrictEqual(mockExpectedResult);
    });
    it('should return empty value for waitingForFreeNodePoolCapacity when group requires approval', () => {
        const availableNodePools = [
            { id: 1, name: 'nodePool1', numberOfNodes: 5 },
            { id: 1, name: 'nodePool2', numberOfNodes: 3 }
        ];
        const allNodePools = [
            { id: 1, name: 'nodePool1', numberOfNodes: 5 },
            { id: 1, name: 'nodePool2', numberOfNodes: 3 },
            { id: 3, name: 'nodePool3', numberOfNodes: 2 }
        ];
        const waitingGroups = [
            { isExternal: false, waitingForFreeNodePoolCapacity: false, requiresApproval: true }
        ];
        const result = rejectWaitingGroupsByNodePools.rejectWaitingGroupsByNodePools(availableNodePools, allNodePools, waitingGroups);
        const mockExpectedResult = {
            waitingGroupsAfterFiltering: [
                { isExternal: false, waitingForFreeNodePoolCapacity: false, requiresApproval: true }
            ],
            waitingForFreeNodePoolCapacity: []
        };
        expect(result).toStrictEqual(mockExpectedResult);
    });
    it('should return empty value for waitingGroupsAfterFiltering when there is no available nodePool for the given group and response value for waitingForFreeNodePoolCapacity when there exists a nodePool in allNodePool for the group', () => {
        const triggerDate = '05-09-2023';
        jest.spyOn(global, 'Date').mockImplementationOnce(() => triggerDate);
        const availableNodePools = [
            { id: 1, name: 'nodePool1', numberOfNodes: 5 },
            { id: 1, name: 'nodePool2', numberOfNodes: 3 }
        ];
        const allNodePools = [
            { id: 1, name: 'nodePool1', numberOfNodes: 5 },
            { id: 1, name: 'nodePool2', numberOfNodes: 3 },
            { id: 3, name: 'nodePool3', numberOfNodes: 2 }
        ];
        const waitingGroups = [
            {
                isExternal: false,
                waitingForFreeNodePoolCapacity: false,
                requiresApproval: false,
                nodePoolName: 'nodePool3',
                rejectionContext: {}
            }
        ];
        const result = rejectWaitingGroupsByNodePools.rejectWaitingGroupsByNodePools(availableNodePools, allNodePools, waitingGroups);
        const mockExpectedResult = {
            waitingGroupsAfterFiltering: [],
            waitingForFreeNodePoolCapacity: [
                {
                    isExternal: false,
                    waitingForFreeNodePoolCapacity: false,
                    requiresApproval: false,
                    nodePoolName: 'nodePool3',
                    rejectionContext: {
                        waitingForFreeNodePoolCapacity: {
                            nodePoolName: 'nodePool3',
                            numberOfNodes: 2,
                            timestamp: new Date()
                        }
                    }
                }
            ]
        };
        expect(result.waitingGroupsAfterFiltering).toStrictEqual(mockExpectedResult.waitingGroupsAfterFiltering);
        expect(result.waitingForFreeNodePoolCapacity).toStrictEqual(mockExpectedResult.waitingForFreeNodePoolCapacity);
        expect(result).toStrictEqual(mockExpectedResult);
    });
});
//# sourceMappingURL=RejectWaitingGroupsByNodePools.test.js.map