"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SyncRepository = void 0;
const node_util_1 = require("node:util");
const microservice_1 = require("@jfrog-pipelines/microservice");
const logger_1 = require("@jfrog-pipelines/logger");
const SyncDataAdapterFactory_1 = require("./SyncDataAdapterFactory");
class SyncRepository {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('SyncRepository');
        this.adapter = SyncDataAdapterFactory_1.SyncDataAdapterFactory.create(microservice_1.AclAdapterDi.api);
    }
    async getPipelineSourcesByIdByQuery(query = '') {
        try {
            const pipelineSources = await this.adapter.getPipelineSourcesByQuery(query);
            const pipelineSourceById = this.groupById(pipelineSources);
            return pipelineSourceById;
        }
        catch (error) {
            this.logger.warn(`Cannot extract PipelineSources for the query: ${query} with error:${(0, node_util_1.inspect)(error)}`);
            throw error;
        }
    }
    groupById(pipelineSources) {
        const pipelineSourceById = {};
        for (const source of pipelineSources) {
            pipelineSourceById[source.id] = source;
        }
        return pipelineSourceById;
    }
}
exports.SyncRepository = SyncRepository;
//# sourceMappingURL=SyncRepository.js.map