"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require('./ActErr.js');
global.request = require('request');
global.util = require('node:util');
const microservice_1 = require("@jfrog-pipelines/microservice");
const logger_1 = require("@jfrog-pipelines/logger");
const metadata_1 = require("@jfrog-pipelines/metadata");
const configuration_1 = require("@jfrog-pipelines/configuration");
const lodash_1 = __importDefault(require("lodash"));
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const StepWorker_1 = require("./StepWorker");
const constants_1 = require("./constants");
global.request = require('request');
global.util = require('node:util');
global._ = require('underscore');
global.async = require('async');
const logLevel = 'info';
const QUEUE_NAME = 'core.stepService';
const serviceEnum = 12;
const cacheContext = {
    defaultCacheStore: "MEMORY",
    enableInMemoryCache: true,
    enableRedisCache: false
};
const options = {
    enum: serviceEnum,
    isAccessEnabled: true,
    models: [
        data_access_layer_1.Step,
        data_access_layer_1.Run,
        data_access_layer_1.Node,
        data_access_layer_1.NodePool,
        data_access_layer_1.Project,
        data_access_layer_1.RunAdjacency,
        data_access_layer_1.Steplet,
        data_access_layer_1.SystemConfig,
        data_access_layer_1.BuildPlaneMessage,
        data_access_layer_1.PipelineSource,
        data_access_layer_1.Pipeline
    ],
    initializers: [new microservice_1.ApiCheckInitializer(serviceEnum)],
    healthChecks: [],
    logLevel: logLevel,
    validator: new microservice_1.DefaultApplicationValidator([], []),
    cacheContext: cacheContext
};
async function startApp() {
    const app = new microservice_1.Application(options, microservice_1.applicationContext);
    const worker = new StepWorker_1.StepWorker();
    global.logger = logger_1.LoggerFactory.getLogger('StepService');
    global.config = {
        apiToken: configuration_1.ConfigFactory.config.apiToken,
        enforceNonRootNodes: configuration_1.ConfigFactory.config.getCustom('runtime.enforceNonRootNodes') ?? false,
        artifactoryUrl: configuration_1.ConfigFactory.config.artifactoryUrl,
        rtServiceId: configuration_1.ConfigFactory.config.rtServiceId
    };
    global.systemConfig = {
        stepTimeoutMS: configuration_1.ConfigFactory.config.stepTimeoutMS
    };
    const systemCodes = (0, metadata_1.getSystemCodes)();
    global.systemCodes = systemCodes;
    global.systemCodesByName = (0, metadata_1.getSystemCodesByName)();
    global.systemCodesByCode = (0, metadata_1.getSystemCodesByCode)();
    global.systemCodesByGroup = lodash_1.default.groupBy(systemCodes, 'group');
    lodash_1.default.each(global.systemCodesByGroup, (groupCodes, group) => {
        global.systemCodesByGroup[group] = lodash_1.default.keyBy(groupCodes, 'name');
    });
    global.logger = logger_1.LoggerFactory.getLogger('StepService');
    global.msName = 'stepService';
    global.request = global.request.defaults({
        headers: {
            Connection: 'keep-alive',
            'Keep-Alive': `timeout=${constants_1.KEEP_ALIVE.TIMEOUT_SEC}, max=${constants_1.KEEP_ALIVE.MAX_CONNECTIONS}`
        }
    });
    await app.listen(QUEUE_NAME, worker);
}
startApp();
//# sourceMappingURL=app.js.map