"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepAffinityIterable = void 0;
const ConsoleLogRepository_1 = require("../queuer/repository/ConsoleLogRepository");
class StepAffinityIterable {
    constructor(items, concurrentQuota) {
        this.items = items.sort((a, b) => a.compareTo(b));
        this.concurrentQuota = concurrentQuota;
        this.consoleRepository = new ConsoleLogRepository_1.ConsoleLogRepository();
    }
    isEmpty() {
        return this.items.length === 0;
    }
    size() {
        return this.items.length;
    }
    async *[Symbol.asyncIterator]() {
        yield await this.next();
    }
    async next() {
        let availableNodes = await this.concurrentQuota.getCurrentExecutionSnapshot();
        const queuableStepAffinity = [];
        while (availableNodes > 0 && this.items.length > 0) {
            queuableStepAffinity.push(this.items.shift());
            availableNodes -= 1;
        }
        if (availableNodes === 0 && this.items.length > 0) {
            await this.handleLicenseBreach();
        }
        return {
            done: queuableStepAffinity.length === 0,
            value: queuableStepAffinity
        };
    }
    async handleLicenseBreach() {
        let stepIds = [];
        for (const item of this.items) {
            const steps = item.getStepsToExecute();
            const stepIdList = steps.map((step) => step.getId());
            stepIds = [...stepIds, ...stepIdList];
        }
        const pipelineId = this.items[0].getPipelineId();
        await this.consoleRepository.publishLicenseBreachedLogs(stepIds, pipelineId);
    }
}
exports.StepAffinityIterable = StepAffinityIterable;
//# sourceMappingURL=StepAffinityIterable.js.map