"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepAffinity = void 0;
class StepAffinity {
    constructor(stepAffinityRunId, group, stepAffinityDag, stepAffinityNodePool, stepAffinitySteps, stepAffinitySteplets, stepAffinityPriority, stepAffinityTriggeredAt, stepAffinityRequiresApproval, stepAffinityUsingLocalRt, stepAffinityWaitingForApproval, stepAffinityPipelineId, stepAffinityPipelineSourceId, stepAffinityExternal) {
        this.runId = stepAffinityRunId;
        this.affinityGroup = group;
        this.dag = stepAffinityDag;
        this.nodePool = stepAffinityNodePool;
        this.steps = stepAffinitySteps;
        this.steplets = stepAffinitySteplets;
        this.priority = stepAffinityPriority;
        this.triggeredAt = stepAffinityTriggeredAt;
        this.requiresApproval = stepAffinityRequiresApproval;
        this.usingLocalArtifactory = stepAffinityUsingLocalRt;
        this.waitingForApproval = stepAffinityWaitingForApproval;
        this.pipelineId = stepAffinityPipelineId;
        this.pipelineSourceId = stepAffinityPipelineSourceId;
        this.external = stepAffinityExternal;
    }
    static create(runId, group, dag, nodePoolAssigned, steps) {
        const affinityGroup = group;
        const nodePool = nodePoolAssigned;
        let steplets = [];
        for (const step of steps) {
            steplets = [...steplets, ...step.getSteplets()];
        }
        if (steplets.length === 0) {
            return null;
        }
        const anySteplet = steplets[0];
        const priority = Math.min(...steplets.map((steplet) => steplet.getPriority()));
        const triggeredAt = new Date(Math.min(...steplets.map((steplet) => steplet.getTriggeredAt().getTime())));
        const requiresApproval = dag.some((record) => [6, 7].includes(record.getDependentEntityType()));
        const usingLocalArtifactory = steps.some((step) => step.hasLocalArtifactory());
        const waitingForApproval = steplets.some((steplet) => steplet.isWaitingForApproval());
        const pipelineId = anySteplet.getPipelineId();
        const pipelineSourceId = anySteplet.getPipelineSourceId();
        const external = steplets.some((steplet) => steplet.isExternal());
        return new StepAffinity(runId, affinityGroup, dag, nodePool, steps, steplets, priority, triggeredAt, requiresApproval, usingLocalArtifactory, waitingForApproval, pipelineId, pipelineSourceId, external);
    }
    getStepsToExecute() {
        return this.steps;
    }
    getRunId() {
        return this.runId;
    }
    getAffinityGroup() {
        return this.affinityGroup;
    }
    getDag() {
        return this.dag;
    }
    getNodePool() {
        return this.nodePool;
    }
    getPriority() {
        return this.priority;
    }
    isExternal() {
        return this.external;
    }
    isApprovalRequired() {
        return this.requiresApproval;
    }
    getSteplets() {
        return this.steplets;
    }
    getTriggeredAt() {
        return this.triggeredAt;
    }
    getProjectId() {
        return this.nodePool?.getProject().getProjectId() ?? null;
    }
    isUsingLocalArtifactory() {
        return this.usingLocalArtifactory;
    }
    isWaitingForApproval() {
        return this.waitingForApproval;
    }
    getPipelineId() {
        return this.pipelineId;
    }
    getApprovalRequestedAt() {
        return this.approvalRequestedAt;
    }
    getPipelineSourceId() {
        return this.pipelineSourceId;
    }
    compareTo(instance) {
        if (this.requiresApproval && !instance.isApprovalRequired()) {
            return -1;
        }
        else if (!this.requiresApproval && instance.isApprovalRequired()) {
            return 1;
        }
        if (this.priority < instance.getPriority()) {
            return -1;
        }
        else if (this.priority > instance.getPriority()) {
            return 1;
        }
        const triggeredTime = new Date(this.triggeredAt).getTime();
        const instanceTriggeredTime = new Date(instance.getTriggeredAt()).getTime();
        if (triggeredTime < instanceTriggeredTime) {
            return -1;
        }
        return 1;
    }
}
exports.StepAffinity = StepAffinity;
//# sourceMappingURL=StepAffinity.js.map