"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConcurrentQuota = void 0;
const LicenseContext_1 = require("./LicenseContext");
const OnSaasLicenseStrategy_1 = require("./strategy/OnSaasLicenseStrategy");
const OnPremLicenseStrategy_1 = require("./strategy/OnPremLicenseStrategy");
const LicenseRepository_1 = require("./repository/LicenseRepository");
class ConcurrentQuota {
    constructor(executionNodeCount) {
        this.maxConcurrentLimit = executionNodeCount;
        this.licenseRepository = new LicenseRepository_1.LicenseRepository();
    }
    static async create(properties) {
        const licenseContext = new LicenseContext_1.LicenseContext();
        if (properties.isSaaS) {
            licenseContext.setStrategy(new OnSaasLicenseStrategy_1.OnSaasLicenseStrategy(properties.nodeLimit));
        }
        else {
            licenseContext.setStrategy(new OnPremLicenseStrategy_1.OnPremLicenseStrategy());
        }
        const nodeLimit = await licenseContext.execute();
        return new ConcurrentQuota(nodeLimit);
    }
    async getCurrentExecutionSnapshot() {
        const stepIdsInProgress = await this.licenseRepository.getStepsInProgress();
        if (stepIdsInProgress === null) {
            return this.maxConcurrentLimit;
        }
        const stepletCount = await this.licenseRepository.getStepletCount(stepIdsInProgress);
        if (stepletCount === null) {
            return this.maxConcurrentLimit;
        }
        return Math.max(0, this.maxConcurrentLimit - stepletCount);
    }
}
exports.ConcurrentQuota = ConcurrentQuota;
//# sourceMappingURL=ConcurrentQuota.js.map