"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LicenseRepository = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const metadata_1 = require("@jfrog-pipelines/metadata");
const StepDao_1 = require("../../../../driven/db/StepDao");
const StepletDao_1 = require("../../../../driven/db/StepletDao");
const PipelinesInfo_1 = require("../vo/PipelinesInfo");
class LicenseRepository {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('LicenseRepository');
        this.stepDao = new StepDao_1.StepDao();
        this.stepletDao = new StepletDao_1.StepletDao();
    }
    async getStepsInProgress() {
        try {
            const incompleteStatusCodes = [metadata_1.WAITING, metadata_1.QUEUED, metadata_1.PROCESSING];
            const query = new data_access_layer_1.SequelizeQueryBuilder({})
                .where('groupInProgress', true)
                .whereWithOperator('statusCode', incompleteStatusCodes, '$in')
                .attributes(['id']);
            const steps = await this.stepDao.findAll(query.build());
            const stepIds = steps.map((step) => step.id);
            return stepIds;
        }
        catch (error) {
            this.logger.warn(`Cannot get steps in progress due to error: ${(0, node_util_1.inspect)(error)}`);
            return null;
        }
    }
    async getStepletCount(stepIds) {
        try {
            const incompleteStatusCodes = [metadata_1.PROCESSING, metadata_1.QUEUED];
            const query = new data_access_layer_1.SequelizeQueryBuilder({})
                .where('stepId', stepIds)
                .whereWithOperator('statusCode', incompleteStatusCodes, '$in')
                .attributes(['id']);
            const steplets = await this.stepletDao.findAll(query.build());
            return steplets.length;
        }
        catch (error) {
            this.logger.warn(`Cannot get stepletCountByStepId ${stepIds.join(',')} due to error:${(0, node_util_1.inspect)(error)}`);
            return null;
        }
    }
    async getPipelinesInfoByMissionControl() {
        try {
            const mcAdapter = await internal_clients_1.MissionControlAdapter.create(12);
            const pipelinesInfo = await mcAdapter.getPipelinesInfo();
            const errors = pipelinesInfo.errors;
            if (errors.length > 0) {
                this.logger.info(`Got ${(0, node_util_1.inspect)(errors)} while extracting pipelines info from Mission Control Adapter`);
                return null;
            }
            return new PipelinesInfo_1.PipelinesInfo(pipelinesInfo);
        }
        catch (error) {
            this.logger.warn('Unable to fetch execution node count from Mission Control: ', (0, node_util_1.inspect)(error));
            return null;
        }
    }
}
exports.LicenseRepository = LicenseRepository;
//# sourceMappingURL=LicenseRepository.js.map