"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Queuer = void 0;
const logger_1 = require("@jfrog-pipelines/logger");
const strategy_1 = require("./strategy");
class Queuer {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('Queuer');
    }
    async queue(stepAffinityIterable) {
        for await (const stepAffinityIterableBatch of stepAffinityIterable) {
            const stepAffinityBatch = stepAffinityIterableBatch.value;
            for (const stepAffinity of stepAffinityBatch) {
                const queuer = this.getQueuer(stepAffinity);
                if (queuer === null) {
                    continue;
                }
                await queuer.queue();
            }
        }
    }
    getQueuer(stepAffinity) {
        if (stepAffinity.isApprovalRequired()) {
            this.logger.debug(`Assigning approval request queuer to stepAffinity with runId: ${stepAffinity.getRunId()} and affinityGroup: ${stepAffinity.getAffinityGroup()}`);
            return new strategy_1.ApprovalRequestQueuer(stepAffinity);
        }
        else if (stepAffinity.isExternal()) {
            this.logger.debug(`Assigning external queuer to stepAffinity with runId: ${stepAffinity.getRunId()} and affinityGroup: ${stepAffinity.getAffinityGroup()}`);
            return new strategy_1.ExternalStepQueuer(stepAffinity);
        }
        else if (stepAffinity.getNodePool()) {
            this.logger.debug(`Assigning nodePool queuer to stepAffinity with runId: ${stepAffinity.getRunId()} and affinityGroup: ${stepAffinity.getAffinityGroup()}`);
            return new strategy_1.NodePoolQueuer(stepAffinity);
        }
        this.logger.warn(`Cannot assign queuer to stepAffinity with runId: ${stepAffinity.getRunId()} and affinity group: ${stepAffinity.getAffinityGroup()}. Bailing out.`);
        return null;
    }
}
exports.Queuer = Queuer;
//# sourceMappingURL=Queuer.js.map