"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuildPlaneMessage = void 0;
const metadata_1 = require("@jfrog-pipelines/metadata");
const logger_1 = require("@jfrog-pipelines/logger");
const repository_1 = require("../repository");
const ConsoleLogRepository_1 = require("../repository/ConsoleLogRepository");
const BuildPlaneMessagePayload_1 = require("./BuildPlaneMessagePayload");
const BuildPlaneMessageStep_1 = require("./vo/BuildPlaneMessageStep");
const BuildPlaneMessageUpdateStep_1 = require("./vo/BuildPlaneMessageUpdateStep");
const BuildPlaneMessageConfigPropertyBag_1 = require("./vo/BuildPlaneMessageConfigPropertyBag");
const BuildPlaneMessageSystemPropertyBag_1 = require("./vo/BuildPlaneMessageSystemPropertyBag");
class BuildPlaneMessage {
    constructor(projectId, pipelineId, runId, payload, nodePoolId, priority, triggeredAt, statusCode, updateStep) {
        this.projectId = projectId;
        this.pipelineId = pipelineId;
        this.runId = runId;
        this.payload = payload;
        this.nodePoolId = nodePoolId;
        this.priority = priority;
        this.triggeredAt = triggeredAt;
        this.statusCode = statusCode;
        this.updateStep = updateStep;
    }
    static async create(stepAffinity, nodePool, stepsToExecute) {
        const consoleLogRepository = new ConsoleLogRepository_1.ConsoleLogRepository();
        const pipelineSourceId = stepAffinity.getPipelineSourceId();
        const projectSource = stepAffinity.getNodePool()?.getProject().getProjectSource() ?? null;
        const idProject = stepAffinity.getNodePool()?.getProject().getProjectId() ?? null;
        if (projectSource === null || idProject === null) {
            BuildPlaneMessage.logger.error(`Could not found project information for the stepIds: ${stepsToExecute
                .map((step) => step.getId())
                .join(',')}`);
            await consoleLogRepository.publishErrorLogsWhenProjectIsInvalid(stepsToExecute.map((step) => step.getId()), stepAffinity.getPipelineId());
            return null;
        }
        const runId = stepAffinity.getRunId();
        const stepsForBuildPlaneMessage = [];
        const priority = stepAffinity.getPriority();
        for (const step of stepsToExecute) {
            const stepletIds = step.getSteplets().map((steplet) => steplet.getId());
            stepsForBuildPlaneMessage.push(new BuildPlaneMessageStep_1.BuildPlaneMessageStep(priority, step.getId(), stepletIds));
        }
        const stepIdsToExecute = stepsToExecute.map((step) => step.getId());
        const instanceSize = nodePool.getInstanceSize();
        const messagePayload = await BuildPlaneMessagePayload_1.BuildPlaneMessagePayload.create(stepAffinity.getAffinityGroup(), stepAffinity.getRunId(), projectSource, idProject, stepIdsToExecute, stepsForBuildPlaneMessage, stepAffinity.isUsingLocalArtifactory(), pipelineSourceId);
        const buildPlaneMessageSystemPropertyBag = await BuildPlaneMessageSystemPropertyBag_1.BuildPlaneMessageSystemPropertyBag.create(runId, stepAffinity.getProjectId());
        const updateStep = new BuildPlaneMessageUpdateStep_1.BuildPlaneMessageUpdateStep(true, new Date(), new BuildPlaneMessageConfigPropertyBag_1.BuildPlaneMessageConfigPropertyBag(nodePool.isDynamic(), instanceSize), buildPlaneMessageSystemPropertyBag);
        const projectId = stepAffinity.getProjectId();
        if (projectId === null) {
            return null;
        }
        return new BuildPlaneMessage(projectId, stepAffinity.getPipelineId(), stepAffinity.getRunId(), messagePayload, nodePool.getId(), stepAffinity.getPriority(), stepAffinity.getTriggeredAt(), metadata_1.READY, updateStep);
    }
    async queue() {
        const nodePoolRepository = new repository_1.NodePoolRepository();
        return nodePoolRepository.queueToNodePool(this);
    }
}
exports.BuildPlaneMessage = BuildPlaneMessage;
BuildPlaneMessage.logger = logger_1.LoggerFactory.getLogger(`BuildPlaneMessage`);
//# sourceMappingURL=BuildPlaneMessage.js.map