"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuildPlaneMessagePayload = void 0;
const node_util_1 = require("node:util");
const utility_1 = require("@jfrog-pipelines/utility");
const repository_1 = require("../repository");
const TokenRepository_1 = require("../repository/TokenRepository");
const ONE_DAY_IN_SECONDS = 86400;
const WILDCARD_AUDIENCE = '*@*';
class BuildPlaneMessagePayload {
    constructor(affinityGroup, runId, stepIds, steps, builderApiToken, builderSetupApiToken, localArtifactoryToken) {
        this.affinityGroup = affinityGroup;
        this.runId = runId;
        this.stepIds = stepIds;
        this.steps = steps;
        this.builderApiToken = builderApiToken;
        this.builderSetupApiToken = builderSetupApiToken;
        this.localArtifactoryToken = localArtifactoryToken;
    }
    static async create(affinityGroup, runId, sourceId, projectId, stepIds, steps, usingLocalArtifactory, pipelineSourceId) {
        const localRtToken = usingLocalArtifactory
            ? await this.createLocalArtifactoryToken(pipelineSourceId, runId, sourceId)
            : undefined;
        const runSetupToken = await this.createRunStepToken(runId, projectId);
        const runExecutionToken = await this.checkAndAddRunExecutionToken(runId, projectId);
        if (localRtToken === null) {
            throw new Error('Cannot generate necessary tokens');
        }
        return new BuildPlaneMessagePayload(affinityGroup, runId, stepIds, steps, runSetupToken, runExecutionToken, localRtToken);
    }
    static async createLocalArtifactoryToken(pipelineSourceId, runId, sourceId) {
        const syncRepository = new repository_1.SyncRepository();
        const artifactoryTokenPermissions = await syncRepository.getArtifactoryTokenPermissions(pipelineSourceId);
        const localArtifactoryIntegrationTokenPermissions = !(0, utility_1.isEmpty)(artifactoryTokenPermissions)
            ? artifactoryTokenPermissions.map((action) => action[0])
            : ['r'];
        const tokenActions = localArtifactoryIntegrationTokenPermissions.join(',');
        const tokenRequest = {
            username: `run-setup-${runId}@jfpip`,
            scope: `artifact:${sourceId}-*:${tokenActions}`,
            refreshable: false,
            audience: WILDCARD_AUDIENCE,
            expiresIn: ONE_DAY_IN_SECONDS,
            grantType: 'client_credentials'
        };
        return TokenRepository_1.TokenRepository.createToken(tokenRequest);
    }
    static async createRunStepToken(runId, projectId) {
        const tokenRequest = {
            username: `run-setup-${runId}@jfpip`,
            scope: `internal:pipelines/project/${(0, node_util_1.inspect)(projectId)}:r,w,d,m`,
            refreshable: false,
            audience: WILDCARD_AUDIENCE,
            expiresIn: ONE_DAY_IN_SECONDS,
            grantType: 'client_credentials'
        };
        return TokenRepository_1.TokenRepository.createToken(tokenRequest);
    }
    static async checkAndAddRunExecutionToken(runId, projectId) {
        const runRepository = new repository_1.RunRepository();
        return runRepository.createAndUpdateRunExecutionToken(runId, projectId);
    }
}
exports.BuildPlaneMessagePayload = BuildPlaneMessagePayload;
//# sourceMappingURL=BuildPlaneMessagePayload.js.map