"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodePoolRepository = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const metadata_1 = require("@jfrog-pipelines/metadata");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const utility_1 = require("@jfrog-pipelines/utility");
const driven_1 = require("../../../../driven");
const NodeDao_1 = require("../../../../driven/acl/nodepool-service/NodeDao");
const NodePoolServiceDataAdapter_1 = require("../../../../driven/acl/nodepool-service/NodePoolServiceDataAdapter");
const NodePoolServiceQueueClient_1 = require("../../../../driven/acl/nodepool-service/NodePoolServiceQueueClient");
class NodePoolRepository {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger(`NodePoolRepository`);
        this.buildPlaneMessageDao = new driven_1.BuildPlaneMessageDao();
        this.nodeDao = new NodeDao_1.NodeDao();
        this.nodePoolDataAdapter = new NodePoolServiceDataAdapter_1.NodePoolServiceDataAdapter();
        this.nodePoolServiceQueueClient = new NodePoolServiceQueueClient_1.NodePoolServiceQueueClient();
    }
    async getBuildPlaneMessageCount(nodePoolId) {
        try {
            const statusCodes = [metadata_1.READY, metadata_1.PROCESSING, metadata_1.QUEUED];
            const query = new data_access_layer_1.SequelizeQueryBuilder({})
                .where('nodePoolId', nodePoolId)
                .whereWithOperator('statusCode', statusCodes, '$in');
            const buildPlaneMessages = await this.buildPlaneMessageDao.count(query.build());
            return buildPlaneMessages;
        }
        catch (error) {
            this.logger.warn(`Cannot get buildPlaneMessage count for nodePoolId: ${nodePoolId} due to error: ${(0, node_util_1.inspect)(error)}`);
            return null;
        }
    }
    async getAvailableNodeCount(nodePoolId) {
        try {
            const statusCodes = [metadata_1.SUCCESS, metadata_1.WAITING, metadata_1.QUEUED, metadata_1.PROCESSING];
            const query = new data_access_layer_1.SequelizeQueryBuilder({})
                .where('nodePoolId', nodePoolId)
                .whereWithOperator('statusCode', statusCodes, '$in');
            const nodeCount = await this.nodeDao.count(query.build());
            return nodeCount;
        }
        catch (error) {
            this.logger.warn(`Cannot get node count for nodePoolId: ${nodePoolId} due to error: ${(0, node_util_1.inspect)(error)}`);
            return 0;
        }
    }
    async queueToNodePool(message) {
        try {
            await this.nodePoolDataAdapter.queueToNodePool(message);
            return true;
        }
        catch (error) {
            this.logger.warn(`Cannot queue message: ${(0, node_util_1.inspect)(message)} due to error: ${(0, node_util_1.inspect)(error)}`);
            return false;
        }
    }
    async publishMessageToNodePoolService(nodePoolId) {
        try {
            const message = {
                payload: {
                    eventType: utility_1.Actor.NODE_POOL_PROCESSING,
                    payload: {
                        id: nodePoolId
                    }
                }
            };
            await this.nodePoolServiceQueueClient.publishMessage(message);
            this.logger.info(`Queued message to nodePoolService`);
            return true;
        }
        catch (error) {
            this.logger.warn(`Cannot post message to nodepool service due to error: ${(0, node_util_1.inspect)(error)}`);
            return false;
        }
    }
}
exports.NodePoolRepository = NodePoolRepository;
//# sourceMappingURL=NodePoolRepository.js.map