"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunRepository = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const RunDao_1 = require("../../../../driven/acl/run-service/RunDao");
const constants_1 = require("../../../../constants");
const TokenRepository_1 = require("./TokenRepository");
const ONE_DAY_IN_SECONDS = 86400;
class RunRepository {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('RunRepository');
        this.runDao = new RunDao_1.RunDao();
    }
    async getTokenFromRun(runId) {
        try {
            const run = await this.runDao.findById(runId);
            const systemPropertyBag = run?.systemPropertyBag;
            if (typeof systemPropertyBag?.token === 'string') {
                return systemPropertyBag.token;
            }
            return null;
        }
        catch (error) {
            this.logger.warn(`For runId ${runId} unable to update token value in systemPropertyBag due to error: ${(0, node_util_1.inspect)(error)}`);
            return null;
        }
    }
    async updateToken(runId, token) {
        try {
            const run = await this.runDao.findById(runId);
            const systemPropertyBag = run?.systemPropertyBag;
            const updatedSystemPropertyBag = { ...systemPropertyBag, token: token };
            await this.runDao.updateByInstance(run, { systemPropertyBag: updatedSystemPropertyBag });
            return true;
        }
        catch (error) {
            this.logger.warn(`Cannot update systemPropertyBag due to error: ${(0, node_util_1.inspect)(error)}`);
            return false;
        }
    }
    async createAndUpdateRunExecutionToken(runId, projectId) {
        const run = await this.runDao.findById(runId);
        const systemPropertyBag = run?.systemPropertyBag;
        if (typeof systemPropertyBag?.token === 'string') {
            return systemPropertyBag.token;
        }
        const tokenRequest = {
            username: `run-${runId}@jfpip`,
            scope: `internal:pipelines/project/${(0, node_util_1.inspect)(projectId)}:r,w,d`,
            refreshable: false,
            audience: constants_1.WILDCARD_AUDIENCE,
            expiresIn: ONE_DAY_IN_SECONDS,
            grantType: 'client_credentials'
        };
        const token = await TokenRepository_1.TokenRepository.createToken(tokenRequest);
        const update = {
            systemPropertyBag: {
                ...run?.systemPropertyBag,
                token: token
            }
        };
        await this.runDao.updateByInstance(run, update);
        return token;
    }
}
exports.RunRepository = RunRepository;
//# sourceMappingURL=RunRepository.js.map