"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SyncRepository = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const PipelineSourceDao_1 = require("../../../../driven/acl/sync-service/PipelineSourceDao");
class SyncRepository {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('SyncRepository');
        this.pipelineSourceDao = new PipelineSourceDao_1.PipelineSourceDao();
    }
    async getArtifactoryTokenPermissions(pipelineSourceId) {
        try {
            const query = new data_access_layer_1.SequelizeQueryBuilder({})
                .where('id', pipelineSourceId)
                .attributes(['artifactoryTokenPermissions']);
            const pipelineSourceAttributes = await this.pipelineSourceDao.findOne(query.build());
            if (pipelineSourceAttributes === null) {
                this.logger.error(`No pipeline source exists for sourceId: ${pipelineSourceId}`);
                return null;
            }
            if (pipelineSourceAttributes.artifactoryTokenPermissions.length === 0) {
                this.logger.warn(`Cannot find artifactory token permissions for pipelineSourceId: ${pipelineSourceId}`);
                return null;
            }
            return pipelineSourceAttributes.artifactoryTokenPermissions;
        }
        catch (error) {
            this.logger.warn(`Cannot get pipelineSourceAttributes with pipelineSourceId: ${pipelineSourceId} due to error: ${(0, node_util_1.inspect)(error)}`);
            return null;
        }
    }
}
exports.SyncRepository = SyncRepository;
//# sourceMappingURL=SyncRepository.js.map