"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApprovalRequestQueuer = void 0;
const node_util_1 = require("node:util");
const logger_1 = require("@jfrog-pipelines/logger");
const StepServiceDataAdapter_1 = require("../../../../driven/db/StepServiceDataAdapter");
const StepRepository_1 = require("../repository/StepRepository");
const ConsoleLogRepository_1 = require("../repository/ConsoleLogRepository");
class ApprovalRequestQueuer {
    constructor(queableStepAffinity) {
        this.queableStepAffinity = queableStepAffinity;
        this.stepServiceDataAdapter = new StepServiceDataAdapter_1.StepServiceDataAdapter();
        this.stepRepository = new StepRepository_1.StepRepository();
        this.consoleLogRepository = new ConsoleLogRepository_1.ConsoleLogRepository();
        this.logger = logger_1.LoggerFactory.getLogger(`${queableStepAffinity
            .getStepsToExecute()
            .map((step) => step.getId())
            .join(',')}:ApprovalRequestQueuer`);
    }
    async queue() {
        if (this.queableStepAffinity.isApprovalRequired() && this.queableStepAffinity.getApprovalRequestedAt()) {
            this.logger.info(`Approval Request already been raised`);
            return;
        }
        const steps = this.queableStepAffinity.getStepsToExecute();
        if (steps.length === 0) {
            this.logger.warn(`No steps found for runId: ${this.queableStepAffinity.getRunId()}, affinityGroup: ${this.queableStepAffinity.getAffinityGroup()}`);
            return;
        }
        const step = steps[0];
        const stepId = step.getId();
        if (this.queableStepAffinity.isWaitingForApproval() === true) {
            return;
        }
        const markedWaitingForApproval = await this.setWaitingForApproval(this.queableStepAffinity);
        if (!markedWaitingForApproval) {
            return;
        }
        await this.consoleLogRepository.publishApprovalRequestLogs([stepId], this.queableStepAffinity.getPipelineId());
        const isExecutableStep = await this.stepServiceDataAdapter.getStepExecutionEligibility(stepId);
        if (isExecutableStep === false) {
            this.logger.warn(`Cannot execute step because step is not elgibile for execution. Skipping step`);
            await this.stepRepository.skipSteps([step]);
            await this.stepRepository.skipSteplets(step.getSteplets());
            await this.consoleLogRepository.publishSkipLogsWhenStepNotEligible([stepId], this.queableStepAffinity.getPipelineId());
            return;
        }
        await this.stepRepository.requestStepApproval(stepId);
        return;
    }
    async setWaitingForApproval(queableStepAffinity) {
        const steplets = queableStepAffinity.getSteplets();
        const stepletIdsSet = new Set(steplets.map((steplet) => steplet.getId()));
        const stepletIds = [...stepletIdsSet.values()];
        if (stepletIds.length === 0) {
            this.logger.warn(`No steplets found for runId:${queableStepAffinity.getRunId()} and affinity group: ${queableStepAffinity.getAffinityGroup()}`);
            return false;
        }
        try {
            await this.stepRepository.setWaitingForApproval(stepletIds[0]);
            return true;
        }
        catch (error) {
            this.logger.warn(`Cannot update waiting for approval value for steplets with Ids: ${stepletIds.join(',')} due to error: ${(0, node_util_1.inspect)(error)} `);
            return false;
        }
    }
}
exports.ApprovalRequestQueuer = ApprovalRequestQueuer;
//# sourceMappingURL=ApprovalRequestQueuer.js.map