"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExternalStepQueuer = void 0;
const logger_1 = require("@jfrog-pipelines/logger");
const repository_1 = require("../repository");
const ConsoleLogRepository_1 = require("../repository/ConsoleLogRepository");
class ExternalStepQueuer {
    constructor(queableStepAffinity) {
        this.queableStepAffinity = queableStepAffinity;
        this.stepRepository = new repository_1.StepRepository();
        this.consoleLogManager = new ConsoleLogRepository_1.ConsoleLogRepository();
        this.logger = logger_1.LoggerFactory.getLogger(`${queableStepAffinity
            .getStepsToExecute()
            .map((step) => step.getId())
            .join(',')}:ExternalStepQueuer`);
    }
    async queue() {
        const steps = this.queableStepAffinity.getStepsToExecute();
        if (steps.length === 0) {
            this.logger.warn(`stepAffinity with runId: ${this.queableStepAffinity.getRunId()}, affinity group: ${this.queableStepAffinity.getAffinityGroup()} has no steps to execute`);
            return;
        }
        const executableStep = steps[0];
        const stepIds = steps.map((step) => step.getId());
        const hookId = executableStep.getHookId();
        if (!hookId) {
            this.logger.error(`Cannot find hookId for the step. Exiting`);
            await this.consoleLogManager.publishErrorLogsWhenHookIsNotAvailable(stepIds, this.queableStepAffinity.getPipelineId());
            return;
        }
        const isUpdated = await this.stepRepository.setReadyAtAndMarkGroupInProgress(executableStep.getId());
        if (!isUpdated) {
            this.logger.warn(`Skipping affinity because unable to mark it in progress, due to network issue`);
            return;
        }
        const messagePayload = {
            action: 'trigger',
            stepId: executableStep.getId()
        };
        const isHookPosted = await this.stepRepository.postHook(hookId, messagePayload);
        if (!isHookPosted) {
            await this.consoleLogManager.publishSkipLogsWhenHookIsNotPosted(stepIds, this.queableStepAffinity.getPipelineId());
            return;
        }
        await this.consoleLogManager.publishExternalQueuerQueuedLogs(stepIds, this.queableStepAffinity.getPipelineId());
    }
}
exports.ExternalStepQueuer = ExternalStepQueuer;
//# sourceMappingURL=ExternalStepQueuer.js.map