"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SchedularHandler = void 0;
const node_util_1 = require("node:util");
const microservice_1 = require("@jfrog-pipelines/microservice");
const utility_1 = require("@jfrog-pipelines/utility");
const logger_1 = require("@jfrog-pipelines/logger");
const domain_1 = require("../domain");
const MS_NAME = utility_1.ServiceMeta[12].friendlyName;
const LOCK_TIMEOUT_IN_MS = 60000;
class SchedularHandler {
    constructor(_jobSchedularCommand, jfrogPipelineSessionId) {
        this.jfrogPipelineSessionId = jfrogPipelineSessionId;
        this.logger = logger_1.LoggerFactory.getLogger(`FeatureAwareSchedularHandler`);
        this.systemInstanceId = microservice_1.applicationContext.get(microservice_1.SYSTEM_SERVICE_INSTANCE_INITIALIZER)
            ?.systemServiceInstancesId;
    }
    async handle() {
        try {
            const lock = await microservice_1.Lock.create(this.systemInstanceId, MS_NAME, LOCK_TIMEOUT_IN_MS);
            if (lock === null) {
                return;
            }
            await lock.obtainLock();
            const schedularRootAggregate = new domain_1.SchedularRootAggregate(lock, this.jfrogPipelineSessionId);
            await schedularRootAggregate.process();
        }
        catch (error) {
            this.logger.info(`Failed to obtain lock due to error: ${(0, node_util_1.inspect)(error)}`);
        }
    }
}
exports.SchedularHandler = SchedularHandler;
//# sourceMappingURL=SchedularHandler.js.map