"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const modules_1 = require("../../modules");
const WaitingStepsByRunAdjacency_1 = require("../WaitingStepsByRunAdjacency");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: { config: { apiUrl: 'http://example.com', controlPlaneVersion: '1.23.6', defaultBatchSize: 100 } }
}));
const mockImplementationRejectWaitingGroupByRunAdjacency = (query) => {
    if (query === 'affinityGroups=first&runIds=1&include=id') {
        return Promise.resolve([{ id: 10 }]);
    }
    else if (query === 'affinityGroups=first&runIds=2&include=id') {
        return Promise.resolve([{ id: 10 }, { id: 11 }]);
    }
    throw new Error('error');
};
describe('getWaitingStepsByRunAdjacencies test cases', () => {
    it('should include group in filtered list when runAdjacency attributes extracted are the same as the currentRunAdjacency attributes', async () => {
        const input = [{ runId: 1, affinityGroup: 'first', runAdjacencyList: [{ id: 10 }] }];
        const spy = jest
            .spyOn(modules_1.ApiDataAdapter.prototype, 'getRunAdjacencyByQuery')
            .mockResolvedValueOnce([{ id: 10 }]);
        const result = await WaitingStepsByRunAdjacency_1.WaitingStepsByRunAdjacency.getWaitingStepsByRunAdjacencies(input);
        const mockExpectedResult = [{ runId: 1, affinityGroup: 'first', runAdjacencyList: [{ id: 10 }] }];
        expect(result).toStrictEqual(mockExpectedResult);
        expect(spy).toBeDefined();
        expect(spy).toHaveBeenCalledTimes(input.length);
    });
    it('should not include group in filtered list when runAdjacency Attributes extracted from dataAdapter is empty', async () => {
        const input = [{ runId: 1, affinityGroup: 'first', runAdjacencyList: [{ id: 10 }] }];
        const spy = jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getRunAdjacencyByQuery').mockResolvedValueOnce([]);
        const result = await WaitingStepsByRunAdjacency_1.WaitingStepsByRunAdjacency.getWaitingStepsByRunAdjacencies(input);
        const mockExpectedResult = [];
        expect(result).toStrictEqual(mockExpectedResult);
        expect(spy).toBeDefined();
        expect(spy).toHaveBeenCalledTimes(input.length);
    });
    it('should not include group in filtered list when runAdjacency Attributes extracted from dataAdapter mismatches with the currentList', async () => {
        const input = [{ runId: 1, affinityGroup: 'first', runAdjacencyList: [{ id: 10 }] }];
        const spy = jest
            .spyOn(modules_1.ApiDataAdapter.prototype, 'getRunAdjacencyByQuery')
            .mockResolvedValueOnce([{ id: 10 }, { id: 11 }]);
        const result = await WaitingStepsByRunAdjacency_1.WaitingStepsByRunAdjacency.getWaitingStepsByRunAdjacencies(input);
        const mockExpectedResult = [];
        expect(result).toStrictEqual(mockExpectedResult);
        expect(spy).toBeDefined();
        expect(spy).toHaveBeenCalledTimes(input.length);
    });
    it('should return filtered list considering the true, false and error conditions', async () => {
        const input = [
            { runId: 1, affinityGroup: 'first', runAdjacencyList: [{ id: 10 }] },
            { runId: 2, affinityGroup: 'first', runAdjacencyList: [{ id: 10 }] },
            { runId: 3, affinityGroup: 'first', runAdjacencyList: [{ id: 10 }] }
        ];
        const spy = jest.spyOn(modules_1.ApiDataAdapter.prototype, 'getRunAdjacencyByQuery').mockImplementation((query) => {
            return mockImplementationRejectWaitingGroupByRunAdjacency(query);
        });
        const result = await WaitingStepsByRunAdjacency_1.WaitingStepsByRunAdjacency.getWaitingStepsByRunAdjacencies(input);
        const mockExpectedResult = [{ runId: 1, affinityGroup: 'first', runAdjacencyList: [{ id: 10 }] }];
        expect(result).toStrictEqual(mockExpectedResult);
        expect(spy).toBeDefined();
        expect(spy).toHaveBeenCalledTimes(input.length);
    });
});
//# sourceMappingURL=WaitingStepsByRunAdjacency.test.js.map